Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(96)

Unified Diff: components/metrics/proto/ukm/source.proto

Issue 2719823003: Convert first contentful paint logging to the new UKM client API (Closed)
Patch Set: renames Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/metrics/proto/ukm/source.proto
diff --git a/components/metrics/proto/ukm/source.proto b/components/metrics/proto/ukm/source.proto
index 165083bf6d6aafc7081f93df19d71fea6b68e34d..2f6dc1f6afe41ec1c0464299539232568814ec9d 100644
--- a/components/metrics/proto/ukm/source.proto
+++ b/components/metrics/proto/ukm/source.proto
@@ -26,6 +26,7 @@ message Source {
// events related to this Source will generally be relative to this timestamp.
optional int64 navigation_time_msec = 3;
- // Time between navigation and the first contentful paint, in milliseconds.
- optional int64 first_contentful_paint_msec = 4;
+ // Time between navigation and the first contentful paint, in
+ // milliseconds. Deprecated. Use ukm::Entry instead.
+ optional int64 first_contentful_paint_msec = 4 [deprecated = true];
}

Powered by Google App Engine
This is Rietveld 408576698